@@ -73,6 +73,11 @@ impl<'info> Validate<'info> for AcceptAuthority<'info> {
             self.rewarder.pending_authority != Pubkey::default(),
             PendingAuthorityNotSet
         );
+        assert_keys_eq!(
+            self.rewarder.pending_authority,
+            self.authority,
+            "pending authority"
+        );
         Ok(())
     }
 }
@@ -133,6 +138,11 @@ impl<'info> Validate<'info> for CreateMiner<'info> {
         assert_ata!(self.miner_vault, self.miner, self.token_mint, "miner vault");
         assert_keys_eq!(self.miner_vault.owner, self.miner, "miner vault owner");
         assert_keys_eq!(self.miner_vault.mint, self.token_mint, "miner vault mint");
+        assert_keys_eq!(
+            self.miner_vault.mint,
+            self.quarry.token_mint_key,
+            "miner vault mint must match quarry mint"
+        );
         assert_keys_eq!(self.quarry.rewarder_key, self.rewarder, "rewarder");
 
         Ok(())
